removeSigner method

  1. @override
Future<void> removeSigner({
  1. required String walletId,
  2. required String signerLocator,
  3. String? approver,
})
override

approver names which recovery method authorizes this operation. It is required by the backend when the wallet holds more than one recovery method, and must be omitted otherwise.

Implementation

@override
Future<void> removeSigner({
  required String walletId,
  required String signerLocator,
  String? approver,
}) async {
  await _service.unregisterSigner(
    walletId,
    signerLocator,
    approver: approver,
  );
}