CrossmintWalletAddSignerResult class final

Constructors

CrossmintWalletAddSignerResult({required CrossmintWalletSigner signer, String? signatureId, String? transactionId, CrossmintJsonMap raw = const <String, Object?>{}})
const
CrossmintWalletAddSignerResult.fromJson(CrossmintJsonMap json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
raw → CrossmintJsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureId String?
final
signer CrossmintWalletSigner
final
transactionId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override